@@ -1,4 +1,4 @@
-from typing import List, Optional, Type
+from typing import List, Optional, Type, Union
 
 import jsonref
 from django.db.models.fields import Field
@@ -22,22 +22,10 @@ class PydanticJsonFieldSerializer(JSONField, Field):
     ):
         super().__init__(*args, **kwargs)
 
+        self.__set_information_for_drf_yasg(pydantic_models)
+
         self.pydantic_models = pydantic_models if pydantic_models else []
 
-        print("Pydantic Field Serializer")
-        print(self.field_name)
-        print(kwargs)
-        print(pydantic_models)
-        print(
-            "schema from model "
-            + str(self.__schema_field_from_argument(pydantic_models))
-        )
-
-        # Set information for swagger generator drf_yasg
-        PydanticJsonFieldSerializer.Meta.swagger_schema_fields = (
-            self.__schema_field_from_argument(pydantic_models)
-        )
-
     def to_representation(self, value):
         value = super().to_representation(value)
 
@@ -65,11 +53,22 @@ class PydanticJsonFieldSerializer(JSONField, Field):
     def __schema_field_from_pydantic(self, pydantic_model: Type[BaseModel]) -> dict:
         return jsonref.loads(pydantic_model.schema_json())
 
-    def __schema_field_from_argument(
+    def __set_information_for_drf_yasg(
         self, pydantic_models: Optional[List[Type[BaseModel]]]
     ):
-        return (
-            self.__schema_field_from_pydantic(pydantic_models[0])
-            if pydantic_models and pydantic_models.__len__() > 0
-            else {}
-        )
+        """Set information for swagger generator drf_yasg"""
+
+        if pydantic_models is None or pydantic_models.__len__() == 0:
+            schema_information = {}
+
+        elif pydantic_models.__len__() > 1:
+            schema_information = {
+                "anyOf": [
+                    self.__schema_field_from_pydantic(model)
+                    for model in pydantic_models
+                ]
+            }
+        else:
+            schema_information = self.__schema_field_from_pydantic(pydantic_models[0])
+
+        PydanticJsonFieldSerializer.Meta.swagger_schema_fields = schema_information
